Documentation
¶
Index ¶
- type Config
- type InMemorySource
- func (s *InMemorySource) Delete(k resource.Key)
- func (s *InMemorySource) Get(key resource.Key) (resource.Entry, error)
- func (s *InMemorySource) Set(k resource.Key, metadata resource.Metadata, item proto.Message)
- func (s *InMemorySource) Start(handler resource.EventHandler) error
- func (s *InMemorySource) Stop()
- type Processor
- type Source
- type State
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Cached mesh config
Mesh meshconfig.Cache
// Domain suffix to use
DomainSuffix string
}
Config used by the runtime
type InMemorySource ¶
type InMemorySource struct {
// contains filtered or unexported fields
}
InMemorySource is an implementation of source.Interface.
func NewInMemorySource ¶
func NewInMemorySource() *InMemorySource
NewInMemorySource returns a new instance of InMemorySource.
func (*InMemorySource) Delete ¶
func (s *InMemorySource) Delete(k resource.Key)
Delete a value in the in-memory store.
func (*InMemorySource) Start ¶
func (s *InMemorySource) Start(handler resource.EventHandler) error
Start implements source.Interface.Start
type Processor ¶
type Processor struct {
// contains filtered or unexported fields
}
Processor is the main control-loop for processing incoming config events and translating them into component configuration
func NewProcessor ¶
func NewProcessor(src Source, distributor publish.Distributor, cfg *Config) *Processor
NewProcessor returns a new instance of a Processor
type Source ¶
type Source interface {
// Start the source interface, provided the EventHandler. The initial state of the underlying
// config store should be reflected as a series of Added events, followed by a FullSync event.
Start(handler resource.EventHandler) error
// Stop the source interface. Upon return from this method, the channel should not be accumulating any
// more events.
Stop()
}
Source to be implemented by a source configuration provider.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package resource contains core abstract types for representing configuration resources.
|
Package resource contains core abstract types for representing configuration resources. |
Click to show internal directories.
Click to hide internal directories.